searchData={"content_type":"text/markdown","items":[{"doc":"Module responsible for starting the Francis server and to wrap the Plug functionality\n\nThis module performs multiple tasks:\n  * Uses the Application module to start the Francis server\n  * Defines the Francis.Router which uses Francis.Plug.Router, :match and :dispatch\n  * Defines the macros get, post, put, delete, patch and ws to define routes for each operation\n\nYou can also set the following options:\n  * :bandit_opts - Options to be passed to Bandit\n  * :plugs - List of plugs to be used by Francis","ref":"Francis.html","title":"Francis","type":"module"},{"doc":"Defines a DELETE route","ref":"Francis.html#delete/2","title":"Francis.delete/2","type":"macro"},{"doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  delete \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#delete/2-examples","title":"Examples - Francis.delete/2","type":"macro"},{"doc":"Defines a GET route","ref":"Francis.html#get/2","title":"Francis.get/2","type":"macro"},{"doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  get \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#get/2-examples","title":"Examples - Francis.get/2","type":"macro"},{"doc":"Defines a PATCH route","ref":"Francis.html#patch/2","title":"Francis.patch/2","type":"macro"},{"doc":"```elixir\ndefmodule Example.Router do\n  use Francis\n\n  patch \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#patch/2-examples","title":"Examples - Francis.patch/2","type":"macro"},{"doc":"Defines a POST route","ref":"Francis.html#post/2","title":"Francis.post/2","type":"macro"},{"doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  post \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#post/2-examples","title":"Examples - Francis.post/2","type":"macro"},{"doc":"Defines a PUT route","ref":"Francis.html#put/2","title":"Francis.put/2","type":"macro"},{"doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  put \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#put/2-examples","title":"Examples - Francis.put/2","type":"macro"},{"doc":"Defines an action for umatched routes and returns 404","ref":"Francis.html#unmatched/1","title":"Francis.unmatched/1","type":"macro"},{"doc":"Defines a WebSocket route that sends text type responses","ref":"Francis.html#ws/2","title":"Francis.ws/2","type":"macro"},{"doc":"```elixir\ndefmodule Example.Router do\n  use Francis\n\n  ws \"/hello\", fn _ ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#ws/2-examples","title":"Examples - Francis.ws/2","type":"macro"},{"doc":"Module that imports required macros from Francis and Plug.Router","ref":"Francis.Plug.Router.html","title":"Francis.Plug.Router","type":"module"},{"doc":"Starts the application by configuring all endpoints servers to run.\n\nNote: to start the endpoint without using this mix task you must set\n`server: true` in your `Phoenix.Endpoint` configuration.","ref":"Mix.Tasks.Francis.Server.html","title":"mix francis.server","type":"task"},{"doc":"Task accepts the same command-line options as `mix run`.\n\nThe `--no-halt` flag is automatically added.","ref":"Mix.Tasks.Francis.Server.html#module-command-line-options","title":"Command line options - mix francis.server","type":"task"},{"doc":"# Francis\n\nSimple boilerplate killer using Plug and Bandit inspired by [Sinatra](https://sinatrarb.com) for Ruby","ref":"readme.html","title":"Francis","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `francis` to your list of dependencies in `mix.exs`:\n\n```elixir\n\ndef deps do\n  [\n    {:francis, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Francis","type":"extras"},{"doc":"To start the server up you can run `mix francis.server` or if you need a iex console you can run with `iex -S mix francis.server`","ref":"readme.html#usage","title":"Usage - Francis","type":"extras"},{"doc":"```elixir\ndefmodule Example do\n  use Francis\n\n  get(\"/\", fn _ -> \" world \" end)\n  get(\"/:name\", fn %{params: %{\"name\" => name}} -> \"hello #{name}\" end)\n\n  ws(\"ws\", fn \"ping\" -> \"pong\" end)\n\n  unmatched(fn _ -> \"not found\" end)\nend\n```","ref":"readme.html#example-of-a-router","title":"Example of a router - Francis","type":"extras"},{"doc":"With the `plugs` option you are able to apply a list of plugs that happen between before dispatching the request.\n\n\nIn the following example we're adding the `Plug.BasicAuth` plug to setup basic authentication on all routes\n\n```elixir\ndefmodule Example do\n  import Plug.BasicAuth\n\n  use Francis, plugs: [{:basic_auth, username: \"test\", password: \"test\"}]\n\n  get(\"/\", fn _ -> \" world \" end)\n  get(\"/:name\", fn %{params: %{\"name\" => name}} -> \"hello #{name}\" end)\n\n  ws(\"ws\", fn \"ping\" -> \"pong\" end)\n\n  unmatched(fn _ -> \"not found\" end)\nend\n```","ref":"readme.html#example-of-a-router-with-plugs","title":"Example of a router with Plugs - Francis","type":"extras"},{"doc":"In your `iex` instance run:\n```elixir\nMix.install([{:francis, \"~> 0.1\"}])\n\ndefmodule Example do\n  use Francis\n\n  get(\"/\", fn _ -> \" world \" end)\n  get(\"/:name\", fn %{params: %{\"name\" => name}} -> \"hello #{name}\" end)\n\n  ws(\"ws\", fn \"ping\" -> \"pong\" end)\n\n  unmatched(fn _ -> \"not found\" end)\n\n  def start(_, _) do\n    children = [{Bandit, [plug: __MODULE__]}]\n    Supervisor.start_link(children, strategy: :one_for_one)\n  end\nend\n\nExample.start()\n```\n\nCheck the folder [example](https://github.com/filipecabaco/francis/tree/main/example) to check the code.","ref":"readme.html#example-using-it-with-mix-install","title":"Example using it with Mix.install - Francis","type":"extras"}]}